==> hazelcast-all-3.0-RC1-sources.jar: com/hazelcast/queue/client/DrainRequest.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.queue.client;

import com.hazelcast.nio.serialization.Data;
import com.hazelcast.nio.serialization.PortableReader;
import com.hazelcast.nio.serialization.PortableWriter;
import com.hazelcast.queue.DrainOperation;
import com.hazelcast.queue.QueuePortableHook;
import com.hazelcast.spi.impl.PortableCollection;
import com.hazelcast.spi.impl.SerializableCollection;
import com.hazelcast.spi.Operation;

import java.io.IOException;
import java.util.Collection;

/**
 * @ali 5/8/13
 */
public class DrainRequest extends QueueRequest {

    int maxSize;

    public DrainRequest() {
    }

    public DrainRequest(String name, int maxSize) {
        super(name);
        this.maxSize = maxSize;
    }

    protected Operation prepareOperation() {
        return new DrainOperation(name, maxSize);
    }

    public int getClassId() {
        return QueuePortableHook.DRAIN;
    }

    protected Object filter(Object response) {
        if (response instanceof SerializableCollection){
            Collection<Data> coll = ((SerializableCollection) response).getCollection();
            return new PortableCollection(coll);
        }
        return super.filter(response);
    }

    public void writePortable(PortableWriter writer) throws IOException {
        super.writePortable(writer);
        writer.writeInt("m",maxSize);
    }

    public void readPortable(PortableReader reader) throws IOException {
        super.readPortable(reader);
        maxSize = reader.readInt("m");
    }
}

==> hazelcast-all-3.3-RC1-sources.jar: com/hazelcast/queue/client/DrainRequest.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.queue.client;

import com.hazelcast.nio.serialization.Data;
import com.hazelcast.nio.serialization.PortableReader;
import com.hazelcast.nio.serialization.PortableWriter;
import com.hazelcast.queue.DrainOperation;
import com.hazelcast.queue.QueuePortableHook;
import com.hazelcast.security.permission.ActionConstants;
import com.hazelcast.security.permission.QueuePermission;
import com.hazelcast.spi.Operation;
import com.hazelcast.spi.impl.PortableCollection;
import com.hazelcast.spi.impl.SerializableCollection;

import java.io.IOException;
import java.security.Permission;
import java.util.Collection;
/**
 * Provides the request service for {@link com.hazelcast.queue.DrainOperation}
 */
public class DrainRequest extends QueueRequest {

    private int maxSize;

    public DrainRequest() {
    }

    public DrainRequest(String name, int maxSize) {
        super(name);
        this.maxSize = maxSize;
    }

    @Override
    protected Operation prepareOperation() {
        return new DrainOperation(name, maxSize);
    }

    @Override
    public int getClassId() {
        return QueuePortableHook.DRAIN;
    }

    @Override
    protected Object filter(Object response) {
        if (response instanceof SerializableCollection) {
            Collection<Data> coll = ((SerializableCollection) response).getCollection();
            return new PortableCollection(coll);
        }
        return super.filter(response);
    }

    @Override
    public void write(PortableWriter writer) throws IOException {
        super.write(writer);
        writer.writeInt("m", maxSize);
    }

    @Override
    public void read(PortableReader reader) throws IOException {
        super.read(reader);
        maxSize = reader.readInt("m");
    }

    @Override
    public Permission getRequiredPermission() {
        return new QueuePermission(name, ActionConstants.ACTION_REMOVE);
    }
}
